<div class="radius callout panel">{% if element.is_dynamic %}
This is a dynamic page element, you can use the full Django template language here with the context: <pre>{{ context_example }}</pre>
{% else %}
This is a static page element, you can write plain text or include HTML and JavaScript{% endif %}
</div>
{% if error %}<div class="radius alert-box alert">Could not save element, errors: {{ error }}</div>{% endif %}
<form>
  <textarea rows="16" name="content">{{ content|safe }}</textarea>
  {% csrf_token %}
</form>