.edit-composer-element {
  border: 1px dashed rgba(0, 0, 0, 0.2);
  border-radius: 3px;
  transition: border-color 300ms ease-out; }
  .edit-composer-element:hover {
    border-color: #008CBA; }
    .edit-composer-element:hover .edit-composer-button {
      background-color: #008CBA;
      opacity: 1; }

.edit-composer-button {
  width: 4rem;
  border-radius: 3px;
  position: relative;
  text-align: center;
  float: right;
  font-size: 0.75rem;
  padding: 0.3rem 0.5rem 0.6rem;
  color: #fff;
  background-color: #008CBA;
  cursor: pointer;
  opacity: 0.5;
  transition: background-color 300ms ease-out;
  transition: opacity 300ms ease-out; }
  .edit-composer-button:hover {
    background-color: #007295 !important; }
